@@ -247,12 +247,14 @@ var gnrmctests = []struct {
 		msg: GNRMC{
 			Time:      Time{true, 22, 05, 16, 0},
 			Validity:  "A",
+			Latitude:  MustParseGPS("5133.82 N"),
+			Longitude: MustParseGPS("00042.24 W"),
 			Speed:     173.8,
 			Course:    231.8,
 			Date:      Date{true, 13, 06, 94},
 			Variation: -4.2,
-			Latitude:  MustParseGPS("5133.82 N"),
-			Longitude: MustParseGPS("00042.24 W"),
+			FFAMode:   "",
+			NavStatus: "",
 		},
 	},
 	{
@@ -261,12 +263,14 @@ var gnrmctests = []struct {
 		msg: GNRMC{
 			Time:      Time{true, 14, 27, 54, 0},
 			Validity:  "A",
+			Latitude:  MustParseGPS("4302.539570 N"),
+			Longitude: MustParseGPS("07920.379823 W"),
 			Speed:     0,
 			Course:    0,
 			Date:      Date{true, 7, 6, 17},
 			Variation: 0,
-			Latitude:  MustParseGPS("4302.539570 N"),
-			Longitude: MustParseGPS("07920.379823 W"),
+			FFAMode:   FAAModeAutonomous,
+			NavStatus: "",
 		},
 	},
 	{
@@ -275,12 +279,14 @@ var gnrmctests = []struct {
 		msg: GNRMC{
 			Time:      Time{true, 10, 5, 38, 0},
 			Validity:  "A",
+			Latitude:  MustParseGPS("5546.27711 N"),
+			Longitude: MustParseGPS("03736.91144 E"),
 			Speed:     0.061,
 			Course:    0,
 			Date:      Date{true, 26, 3, 18},
 			Variation: 0,
-			Latitude:  MustParseGPS("5546.27711 N"),
-			Longitude: MustParseGPS("03736.91144 E"),
+			FFAMode:   FAAModeAutonomous,
+			NavStatus: "",
 		},
 	},
 	{
@@ -383,6 +389,7 @@ var gpglltests = []struct {
 				Millisecond: 0,
 			},
 			Validity: "A",
+			FFAMode:  FAAModeAutonomous,
 		},
 	},
 	{
@@ -600,12 +607,14 @@ var gprmctests = []struct {
 		msg: GPRMC{
 			Time:      Time{true, 22, 5, 16, 0},
 			Validity:  "A",
+			Latitude:  MustParseGPS("5133.82 N"),
+			Longitude: MustParseGPS("00042.24 W"),
 			Speed:     173.8,
 			Course:    231.8,
 			Date:      Date{true, 13, 6, 94},
 			Variation: -4.2,
-			Latitude:  MustParseGPS("5133.82 N"),
-			Longitude: MustParseGPS("00042.24 W"),
+			FFAMode:   "",
+			NavStatus: "",
 		},
 	},
 	{
@@ -614,12 +623,14 @@ var gprmctests = []struct {
 		msg: GPRMC{
 			Time:      Time{true, 14, 27, 54, 0},
 			Validity:  "A",
+			Latitude:  MustParseGPS("4302.539570 N"),
+			Longitude: MustParseGPS("07920.379823 W"),
 			Speed:     0,
 			Course:    0,
 			Date:      Date{true, 7, 6, 17},
 			Variation: 0,
-			Latitude:  MustParseGPS("4302.539570 N"),
-			Longitude: MustParseGPS("07920.379823 W"),
+			FFAMode:   FAAModeAutonomous,
+			NavStatus: "",
 		},
 	},
 	{
