@@ -59,7 +59,7 @@ type GNS struct {
 }
 
 // newGNS Constructor
-func newGNS(s BaseSentence) (GNS, error) {
+func newGNS(s BaseSentence) (Sentence, error) {
 	p := NewParser(s)
 	p.AssertType(TypeGNS)
 	m := GNS{
@@ -79,13 +79,10 @@ func newGNS(s BaseSentence) (GNS, error) {
 		m.NavStatus = p.EnumString(
 			12,
 			"navigation status",
-			NavStatusAutonomous,
-			NavStatusDifferential,
-			NavStatusEstimated,
-			NavStatusManualInput,
-			NavStatusSimulated,
-			NavStatusDataNotValid,
-			NavStatusDataValid,
+			NavStatusSafe,
+			NavStatusCaution,
+			NavStatusUnsafe,
+			NavStatusNotValid,
 		)
 	}
 	return m, p.Err()
