@@ -24,6 +24,19 @@ var gsatests = []struct {
 			VDOP:    2.4,
 		},
 	},
+	{
+		name: "good sentence with system id",
+		raw:  "$GNGSA,A,3,13,12,22,19,08,21,,,,,,,1.05,0.64,0.83,4*0B",
+		msg: GSA{
+			Mode:     "A",
+			FixType:  "3",
+			SV:       []string{"13", "12", "22", "19", "08", "21"},
+			PDOP:     1.05,
+			HDOP:     0.64,
+			VDOP:     0.83,
+			SystemID: 4,
+		},
+	},
 	{
 		name: "bad mode",
 		raw:  "$GPGSA,F,3,22,19,18,27,14,03,,,,,,,3.1,2.0,2.4*31",
