@@ -24,7 +24,7 @@ type VTG struct {
 
 // newVTG parses the VTG sentence into this struct.
 // e.g: $GPVTG,360.0,T,348.7,M,000.0,N,000.0,K*43
-func newVTG(s BaseSentence) (VTG, error) {
+func newVTG(s BaseSentence) (Sentence, error) {
 	p := NewParser(s)
 	p.AssertType(TypeVTG)
 	vtg := VTG{
